NuRadioReco\.modules\.io package
================================

Subpackages
-----------

.. toctree::

    NuRadioReco.modules.io.araroot
    NuRadioReco.modules.io.coreas
    NuRadioReco.modules.io.noise
    NuRadioReco.modules.io.snowshovel

Submodules
----------

NuRadioReco\.modules\.io\.NuRadioRecoio module
----------------------------------------------

.. automodule:: NuRadioReco.modules.io.NuRadioRecoio
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.io\.eventReader module
--------------------------------------------

.. automodule:: NuRadioReco.modules.io.eventReader
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.io\.eventWriter module
--------------------------------------------

.. automodule:: NuRadioReco.modules.io.eventWriter
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.modules.io
    :members:
    :undoc-members:
    :show-inheritance:
